pytilities.types._sequencetypemeta — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »

# pytilities.types._sequencetypemeta

class `pytilities.types._sequencetypemeta.` `_SequenceTypeMeta`
  `__instancecheck__`(instance)
  `__subclasscheck__`(subclass)

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »